#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = "ecovacs_robot_mcp"
DESCRIPTION = """## Overview
Ecovacs MCP Server

## Key Features

### Comprehensive API - MCP Integration
Ecovacs has successfully completed the integration of 4 core API interfaces with the MCP protocol. These interfaces cover a wide range of essential functions:
- **Device List Query**: Effortlessly retrieve information about all connected Ecovacs robots, enabling easy management and monitoring.
- **Cleaning Control**: Take full control of the cleaning process. Start, pause, or stop cleaning tasks according to your needs.
- **Recharging Control**: Ensure your robots are always ready for action by initiating recharging commands at the right time.
- **Working Status Query**: Stay informed about the current state of your robots, including battery level, cleaning progress, and more."""
URL = "https://github.com/ecovacs-ai/ecovacs-mcp"
EMAIL = "haiyuan.lu@ecovacs.com"
AUTHOR = "Ecovacs"
REQUIRES_PYTHON = ">=3.8.0"
VERSION = "0.1.9"

# What packages are required for this module to be executed?
REQUIRED = ["httpx", "pydantic", "mcp"]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, "README.rst"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Pushing git tags…")
        os.system("git push --tags")

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/x-rst",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    py_modules=['ecovacs_robot_mcp'],
    entry_points={
        "console_scripts": [
            "ecovacs-robot-mcp=ecovacs_robot_mcp:main",
        ]
    },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    # $ setup.py publish support.
    cmdclass={"upload": UploadCommand},
)